==> pycrate-0.5.2.tar.gz: pycrate-0.5.2/pycrate_mobile/__init__.py <==
# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2016. Benoit Michau. ANSSI.
# * Copyright 2019. Benoit Michau. P1Sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_mobile/__init__.py
# * Created : 2016-04-28
# * Authors : Benoit Michau 
# *--------------------------------------------------------
#*/
#
__all__ = ['GSMTAP', 'MCC_MNC', 'PPP', 'SIGTRAN', 'SCCP', 'ISUP',
           'TS24007', 'NAS', 'NASLTE',
           'TS24008_IE', 'TS24008_MM', 'TS24008_GMM', 'TS24008_CC', 'TS24008_SM',
           'TS23038', 'TS23040_SMS', 'TS23041_CBS', 'TS24011_PPSMS', 'TS24080_SS',
           'TS24301_IE', 'TS24301_EMM', 'TS24301_ESM',
           'TS24501_IE', 'TS24501_FGMM', 'TS24501_FGSM', 'TS24501_UEPOL', 'TS24526_UEPOL',
           'TS24588_UEPOL', 'TS24519_TSNAF',
           'TS29002_MAPAppCtx', 'TS29002_MAPIE', 'TS29274_GTPC', 'TS29281_GTPU',
           'TS29244_PFCP',
           'TS44018_IE', 'TS44018_RR', 'TS44018_GTTP', 'TS48058_Abis']

==> pycrate-0.6.0.tar.gz: pycrate-0.6.0/pycrate_mobile/__init__.py <==
# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.5
# *
# * Copyright 2016. Benoit Michau. ANSSI.
# * Copyright 2019. Benoit Michau. P1Sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_mobile/__init__.py
# * Created : 2016-04-28
# * Authors : Benoit Michau 
# *--------------------------------------------------------
#*/
#
__all__ = ['GSMTAP', 'MCC_MNC', 'PPP', 'SIGTRAN', 'SCCP', 'ISUP',
           'TS24007', 'NAS', 'NASLTE', 'NAS5G',
           'TS24008_IE', 'TS24008_MM', 'TS24008_GMM', 'TS24008_CC', 'TS24008_SM',
           'TS23038', 'TS23040_SMS', 'TS23041_CBS', 'TS24011_PPSMS', 'TS24080_SS',
           'TS24301_IE', 'TS24301_EMM', 'TS24301_ESM',
           'TS24501_IE', 'TS24501_FGMM', 'TS24501_FGSM', 'TS24501_UEPOL', 'TS24526_UEPOL',
           'TS24588_UEPOL', 'TS24519_TSNAF', 'TS24193_ATSSS',
           'TS29002_MAPAppCtx', 'TS29002_MAPIE',
           'TS29274_GTPC', 'TS29281_GTPU', 'TS29060_GTP', 'TS0960_GTPv0',
           'TS38415_PDUSess', 'TS29244_PFCP',
           'TS44018_IE', 'TS44018_RR', 'TS44018_GTTP', 'TS48058_Abis',
           'TS102225', 'TS31115', 'TS31111_SAT']
